@@ -1,11 +1,8 @@
 <?php
 /**
  * @license   http://www.horde.org/licenses/gpl GPLv2
- *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
- *            Version 2, the distribution of the Horde_ActiveSync module in or
- *            to the United States of America is excluded from the scope of this
- *            license.
- * @copyright 2012-2017 Horde LLC (http://www.horde.org)
+ *
+ * @copyright 2012-2020 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -15,11 +12,8 @@
  * Horde's Horde_Imap_Client library.
  *
  * @license   http://www.horde.org/licenses/gpl GPLv2
- *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
- *            Version 2, the distribution of the Horde_ActiveSync module in or
- *            to the United States of America is excluded from the scope of this
- *            license.
- * @copyright 2012-2017 Horde LLC (http://www.horde.org)
+ *
+ * @copyright 2012-2020 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -52,6 +46,13 @@ class Horde_ActiveSync_Imap_Adapter
      */
     protected $_procid;
 
+    /**
+     * Additional options
+     *
+     * @since  2.40.0
+     */
+    protected $_options = array();
+
     /**
      * Cont'r
      *
@@ -68,6 +69,17 @@ class Horde_ActiveSync_Imap_Adapter
         $this->_logger = new Horde_ActiveSync_Log_Logger(new Horde_Log_Handler_Null());
     }
 
+    /**
+     * Set additional options for this request.
+     *
+     * @param array $options [description]
+     * @since  2.40.0
+     */
+    public function setOptions(array $options)
+    {
+        $this->_options = $options;
+    }
+
     /**
      * Append a message to the specified mailbox. Used for saving sent email.
      *
@@ -95,7 +107,7 @@ class Horde_ActiveSync_Imap_Adapter
             return false;
         }
 
-        return array_pop($ids->ids);
+        return array_slice($ids->ids, -1)[0];
     }
 
     /**
@@ -238,7 +250,7 @@ class Horde_ActiveSync_Imap_Adapter
         if (empty($messages[$uid]) || !$messages[$uid]->exists(Horde_Imap_Client::FETCH_STRUCTURE)) {
             throw new Horde_ActiveSync_Exception('Message Gone');
         }
-        $msg = new Horde_ActiveSync_Imap_Message($imap, $mbox, $messages[$uid]);
+        $msg = new Horde_ActiveSync_Imap_Message($imap, $mbox, $messages[$uid], $this->_options);
         $part = $msg->getMimePart($part);
 
         return $part;
@@ -293,7 +305,7 @@ class Horde_ActiveSync_Imap_Adapter
         $res = array();
         foreach ($messages as $id => $message) {
             if ($message->exists(Horde_Imap_Client::FETCH_STRUCTURE)) {
-                $res[$id] = new Horde_ActiveSync_Imap_Message($this->_getImapOb(), $mbox, $message);
+                $res[$id] = new Horde_ActiveSync_Imap_Message($this->_getImapOb(), $mbox, $message, $this->_options);
             }
         }
 
@@ -793,7 +805,7 @@ class Horde_ActiveSync_Imap_Adapter
             ? Horde_ActiveSync::VERSION_TWOFIVE
             : $options['protocolversion'];
 
-        $imap_message = new Horde_ActiveSync_Imap_Message($this->_getImapOb(), $mbox, $data);
+        $imap_message = new Horde_ActiveSync_Imap_Message($this->_getImapOb(), $mbox, $data, $this->_options);
 
         // Build the message body.
         $easBodyBuilder = Horde_ActiveSync_Imap_EasMessageBuilder::create(
