@@ -1,11 +1,8 @@
 <?php
 /**
  * @license   http://www.horde.org/licenses/gpl GPLv2
- *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
- *            Version 2, the distribution of the Horde_ActiveSync module in or
- *            to the United States of America is excluded from the scope of this
- *            license.
- * @copyright 2012-2017 Horde LLC (http://www.horde.org)
+ *
+ * @copyright 2012-2020 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -15,11 +12,8 @@
  * structure. I.e., BodyTypePreference == Horde_ActiveSync::BODYPREF_TYPE_MIME.
  *
  * @license   http://www.horde.org/licenses/gpl GPLv2
- *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
- *            Version 2, the distribution of the Horde_ActiveSync module in or
- *            to the United States of America is excluded from the scope of this
- *            license.
- * @copyright 2012-2017 Horde LLC (http://www.horde.org)
+ *
+ * @copyright 2012-2020 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -35,9 +29,6 @@ class Horde_ActiveSync_Imap_EasMessageBuilder_Mime extends Horde_ActiveSync_Imap
         Horde_ActiveSync_Imap_Message $imap_message, array $options, $logger)
     {
         parent::__construct($imap_message, $options, $logger);
-        $this->_easMessage->airsyncbasenativebodytype = $this->_mbd->html
-            ? Horde_ActiveSync::BODYPREF_TYPE_HTML
-            : Horde_ActiveSync::BODYPREF_TYPE_PLAIN;
 
         $this->_airsyncBody->type = Horde_ActiveSync::BODYPREF_TYPE_MIME;
     }
