@@ -3,11 +3,8 @@
  * Horde_ActiveSync_Mime::
  *
  * @license   http://www.horde.org/licenses/gpl GPLv2
- *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
- *            Version 2, the distribution of the Horde_ActiveSync module in or
- *            to the United States of America is excluded from the scope of this
- *            license.
- * @copyright 2012-2017 Horde LLC (http://www.horde.org)
+ *
+ * @copyright 2012-2020 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  * @since 2.19.0
@@ -17,11 +14,8 @@
  * the context of ActiveSync requests.
  *
  * @license   http://www.horde.org/licenses/gpl GPLv2
- *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
- *            Version 2, the distribution of the Horde_ActiveSync module in or
- *            to the United States of America is excluded from the scope of this
- *            license.
- * @copyright 2012-2017 Horde LLC (http://www.horde.org)
+ *
+ * @copyright 2012-2020 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  * @since 2.19.0
@@ -267,4 +261,15 @@ class Horde_ActiveSync_Mime
         return null;
     }
 
-}
\ No newline at end of file
+    /**
+     * Replace the specified MimePart with the provided part.
+     *
+     * @param string $id               The part id of the part to replace.
+     * @param Horde_Mime_Part $newPart The new mimePart.
+     */
+    public function alterPart($id, $newPart)
+    {
+        $this->_base[$id] = $newPart;
+    }
+
+}
