@@ -14,11 +14,8 @@
  *   Consult COPYING file for details
  *
  * @license   http://www.horde.org/licenses/gpl GPLv2
- *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
- *            Version 2, the distribution of the Horde_ActiveSync module in or
- *            to the United States of America is excluded from the scope of this
- *            license.
- * @copyright 2009-2017 Horde LLC (http://www.horde.org)
+ *
+ * @copyright 2009-2020 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -26,11 +23,8 @@
  * Handle Sync requests
  *
  * @license   http://www.horde.org/licenses/gpl GPLv2
- *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
- *            Version 2, the distribution of the Horde_ActiveSync module in or
- *            to the United States of America is excluded from the scope of this
- *            license.
- * @copyright 2009-2017 Horde LLC (http://www.horde.org)
+ *
+ * @copyright 2009-2020 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  * @internal
@@ -974,7 +968,7 @@ class Horde_ActiveSync_Request_Sync extends Horde_ActiveSync_Request_SyncBase
                             $collection['class'], $collection['synckey']
                         );
                         if (is_array($ires) && !empty($ires['error'])) {
-                            $collection['importedfailures'][$ires[0]] = $ires['error'];
+                            $collection['importfailures'][$ires[0]] = $ires['error'];
                         } elseif (is_array($ires)) {
                             $collection['importedchanges'] = true;
                             if (empty($collection['modifiedids'])) {
