@@ -14,11 +14,8 @@
  *   Consult COPYING file for details
  *
  * @license   http://www.horde.org/licenses/gpl GPLv2
- *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
- *            Version 2, the distribution of the Horde_ActiveSync module in or
- *            to the United States of America is excluded from the scope of this
- *            license.
- * @copyright 2009-2017 Horde LLC (http://www.horde.org)
+ *
+ * @copyright 2009-2020 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -26,11 +23,8 @@
  * ActiveSync specific WBXML decoder.
  *
  * @license   http://www.horde.org/licenses/gpl GPLv2
- *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
- *            Version 2, the distribution of the Horde_ActiveSync module in or
- *            to the United States of America is excluded from the scope of this
- *            license.
- * @copyright 2009-2017 Horde LLC (http://www.horde.org)
+ *
+ * @copyright 2009-2020 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -145,7 +139,9 @@ class Horde_ActiveSync_Wbxml_Decoder extends Horde_ActiveSync_Wbxml
     public function getElement()
     {
         $element = $this->getToken();
-
+        if (empty($element)) {
+            return false;
+        }
         switch ($element[self::EN_TYPE]) {
         case self::EN_TYPE_STARTTAG:
             return $element;
@@ -288,7 +284,10 @@ class Horde_ActiveSync_Wbxml_Decoder extends Horde_ActiveSync_Wbxml
         }
 
         $el = $this->_getToken();
-        $this->_logToken($el);
+
+        if (!empty($el)) {
+            $this->_logToken($el);
+        }
 
         return $el;
     }
@@ -349,7 +348,7 @@ class Horde_ActiveSync_Wbxml_Decoder extends Horde_ActiveSync_Wbxml
             switch ($byte) {
             case self::SWITCH_PAGE:
                 $this->_tagcp = $this->_getByte();
-                continue;
+                break;
 
             case self::END:
                 $element[self::EN_TYPE] = self::EN_TYPE_ENDTAG;
@@ -377,12 +376,12 @@ class Horde_ActiveSync_Wbxml_Decoder extends Horde_ActiveSync_Wbxml
             case self::EXT_I_2:
                 $this->_getTermStr();
                 // Ignore extensions
-                continue;
+                break;
 
             case self::PI:
                 // Ignore PI
                 $this->_getAttributes();
-                continue;
+                break;
 
             case self::LITERAL_C:
                 $element[self::EN_TYPE] = self::EN_TYPE_STARTTAG;
@@ -395,7 +394,7 @@ class Horde_ActiveSync_Wbxml_Decoder extends Horde_ActiveSync_Wbxml
             case self::EXT_T_2:
                 $this->_getMBUInt();
                 // Ingore extensions;
-                continue;
+                break;
 
             case self::STR_T:
                 $element[self::EN_TYPE] = self::EN_TYPE_CONTENT;
@@ -411,7 +410,7 @@ class Horde_ActiveSync_Wbxml_Decoder extends Horde_ActiveSync_Wbxml
             case self::EXT_0:
             case self::EXT_1:
             case self::EXT_2:
-                continue;
+                break;
 
             case self::OPAQUE:
                 $length = $this->_getMBUInt();
@@ -513,7 +512,7 @@ class Horde_ActiveSync_Wbxml_Decoder extends Horde_ActiveSync_Wbxml
             case self::EXT_I_1:
             case self::EXT_I_2:
                 $this->_getTermStr();
-                continue;
+                break;
 
             case self::PI:
             case self::LITERAL_C:
@@ -524,7 +523,7 @@ class Horde_ActiveSync_Wbxml_Decoder extends Horde_ActiveSync_Wbxml
             case self::EXT_T_1:
             case self::EXT_T_2:
                 $this->_getMBUInt();
-                continue;
+                break;
 
             case self::STR_T:
                 $attr .= $this->_getStringTableEntry($this->_getMBUInt());
@@ -536,7 +535,7 @@ class Horde_ActiveSync_Wbxml_Decoder extends Horde_ActiveSync_Wbxml
             case self::EXT_0:
             case self::EXT_1:
             case self::EXT_2:
-                continue;
+                break;
 
             case self::OPAQUE:
                 $length = $this->_getMBUInt();
